@@ -5,16 +5,13 @@
 #  Written by: Zsolt T. Kosztyan, Aamir Saghir                                #
 #              Department of Quantitative Methods                             #
 #              University of Pannonia, Hungary                                #
-#              kzst@gtk.uni-pannon.hu                                         #
+#              kosztyan.zsolt@gtk.uni-pannon.hu                               #
 #                                                                             #
-# Last modified: May 2022                                                     #
+# Last modified: June 2024                                                    #
 #-----------------------------------------------------------------------------#
 
 #' @export
 tpc <- function(DSM,CD){
-  TPC<-0
-  for (i in 1:length(CD)){
-    TPC=TPC+as.numeric(DSM[i,i])*as.numeric(CD[i])
-  }
+  TPC<-sum(ceiling(as.numeric(diag(DSM)))*as.numeric(CD))
   return(as.numeric(TPC))
 }
